@@ -1,4 +1,5 @@
+#' @importFrom prcbench
+
 library(testthat)
-library(prcbench)
 
 test_check("prcbench")
